@@ -3,7 +3,7 @@
 # Apache::Session::Generate::MD5;
 # Generates session identifier tokens using MD5
 # Copyright(c) 2000, 2001 Jeffrey William Baker (jwbaker@acm.org)
-# Distribute under the Artistic License
+# Distribute under the Perl License
 #
 ############################################################################
 
@@ -13,7 +13,7 @@ use strict;
 use vars qw($VERSION);
 use Digest::MD5;
 
-$VERSION = '2.1';
+$VERSION = '2.11';
 
 sub generate {
     my $session = shift;
@@ -37,7 +37,7 @@ sub validate {
     my $session = shift;
     
     if ($session->{data}->{_session_id} !~ /^[a-fA-F0-9]+$/) {
-        die;
+        die "Invalid session ID: ".$session->{data}->{_session_id};
     }
 }
 
@@ -52,7 +52,7 @@ Apache::Session::Generate::MD5 - Use MD5 to create random object IDs
 =head1 SYNOPSIS
 
  use Apache::Session::Generate::MD5;
- 
+
  $id = Apache::Session::Generate::MD5::generate();
 
 =head1 DESCRIPTION
